@@ -174,14 +174,15 @@ def main(args=None):
             
 # C.1.ii) Netcdf file        
             try:
-                dir_out = cfg.scc['output-dir']
-                geom_dts = \
+            	dir_out = os.path.join(cfg.scc['output-dir'],rpath[i])
+            	geom_dts = \
                     export_nc(geom, metadata = metadata[i], alpha = alphas[i], 
                               wave = wave[i], snr_factor = snr_factor[i], 
                               wct_peak_margin = wct_peak_margin[i], 
                               ltool_ver = __version__, fname = fname, 
                               dir_out = dir_out)
             except Exception as e:
+                logger.info(dir_out)
                 logger.error("Error while creating the netcdf files ")
                 sys.exit(9)
             logger.info("       Exporting in NetCDF format succesfully completed ")
@@ -196,7 +197,6 @@ def main(args=None):
             try:
                 fpath = os.path.join(rpath[i],fname)
                 update(fpath, meas_id = meas_id, prod_id = ids[i], cfg = cfg)
-                print(rpath[i])
             except Exception as e:
                 logger.error("Error while updating the scc database ")
                 sys.exit(10)         
